@@ -1,7 +1,7 @@
 from botty_core import Handler, PTBContext
 from telegram import Update, ext
 
-from botty.contexts import MessageContext, MessageCallback
+from botty.contexts import MessageCallback, MessageContext
 
 
 class MessageHandler(ext.MessageHandler[PTBContext], Handler[MessageContext]):
